import request from '@/config/axios'

export interface RoomBedVO {
  roomId: number | null // 诊室编号
  bedNo: string | null // 诊疗床编号
}

export interface PatientVO {
  roomId: number // 诊室编号
  bedNo: string // 诊疗床编号
  patId: string // 患者编号
  jumpFlag: number // 插队标记
}

export interface PatientStatisticVO {
  finishedNum: number
  readyNum: number
  passedNum: number
  queuingNum: number
}

// 医生 API
export const DoctorApi = {

  // 看完，取下一位患者
  finishNextPatient: async (params: RoomBedVO) => {
    return await request.get({ url: `/ecg/doctor/finish-next-patient`, params })
  },

  // 过号，取下一位患者
  passNextPatient: async (params: RoomBedVO) => {
    return await request.get({ url: `/ecg/doctor/pass-next-patient`, params })
  },

  // 取初始患者列表
  getPatientList: async (params: RoomBedVO) => {
    return await request.get({ url: `/ecg/doctor/get-patient-list`, params })
  },

  // 取患者统计
  getPatientStatistic: async (params: RoomBedVO) => {
    return await request.get({ url: `/ecg/doctor/get-patient-statistic`, params })
  },

  // 召回过号患者
  recallPatient: async (params: PatientVO) => {
    return await request.get({ url: `/ecg/doctor/recall-patient`, params })
  },

  // 召回过号患者
  patientJump: async (params: PatientVO) => {
    return await request.get({ url: `/ecg/doctor/patient-jump`, params })
  }

}
